export(fit_bayesian)
export(extend)
export(matchalign)
export(delta_grid)
export(qsort_data)
export(validate_qsort)
export(check_distribution)
export(infer_distribution)
export(parse_distribution)
export(read_qsort)
export(read_qsort_csv)
export(read_qsort_excel)
export(read_pqmethod)
export(read_kenq)
export(read_kenq_excel)
export(read_kade_zip)
export(read_easyhtml_firebase)
export(read_statements)
export(import.pqmethod)
export(import.htmlq)
export(import.kenq)
export(import.easyhtmlq)
export(generate_data)
export(generate_loadings)
export(generate_noise)
export(discretize_to_grid)
export(get_distribution)
export(assess_recovery)
export(assess_classification)
export(tucker_congruence)
export(procrustes_rotation)
export(demo_fit)
export(compute_loadings)
export(compute_flags)
export(compute_zscores)
export(compute_factor_array)
export(compute_qdc)
export(factor_characteristics)
export(crib_sheet)
export(claims)
export(check_fit)
export(check_persons)
export(fit_ladder)
export(select_k)
export(loo_ladder)
export(loglik_person)
export(plot_sorts)
export(plot_zscores)
export(plot_statement)
export(plot_zscore_posterior)
export(plot_loading_posterior)
export(plot_flags)
export(plot_factor_array)
export(plot_contrasts)
export(plot_choice_k)
export(plot_person_check)
export(plot_convergence)
export(plot_ppc)
export(plot_membership)
export(plot_dist_cons)
export(plot_hyper)
export(caption_bayesqm)
export(plot_tucker)
export(plot_elpd)
export(make_elpd_diff)
export(make_ppc_ridge)
export(make_dominant_panel)
export(rotate_factors)
export(flip_factor)
export(rename_factors)
export(bayesqm_colors)
export(bayesqm_set_colors)
export(save_bayesqm_plot)
export(posterior_interval)
export(prior_summary)
export(run_bayes)
export(select_k_peak)
export(select_k_sivula)
export(compute_threshold_prob)
export(compute_dominant_prob)
export(compute_dominant_sign)
export(compute_divergence)
export(classify_membership)
export(suggest_delta)
export(critical_delta)
export(compute_posterior_scalars)
export(demo_run)

S3method(print, qsort_data)
S3method(summary, qsort_data)
S3method(as.matrix, qsort_data)
S3method(print, bayesqm_fit)
S3method(summary, bayesqm_fit)
S3method(coef, bayesqm_fit)
S3method(fitted, bayesqm_fit)
S3method(residuals, bayesqm_fit)
S3method(nobs, bayesqm_fit)
S3method(sigma, bayesqm_fit)
S3method(family, bayesqm_fit)
S3method(print, bayesqm_family)
S3method(as.matrix, bayesqm_fit)
S3method(as.array, bayesqm_fit)
S3method(as.data.frame, bayesqm_fit)
S3method(update, bayesqm_fit)
S3method(posterior_interval, bayesqm_fit)
S3method(prior_summary, bayesqm_fit)
S3method(print, bayesqm_prior)
S3method(print, bayesqm_claims)
S3method(print, bayesqm_checks)
S3method(print, bayesqm_persons)
S3method(print, bayesqm_selection)
S3method(plot, bayesqm_fit)
S3method(plot, qsort_data)

importFrom(stats, coef, cor, density, family, fitted,
           median, nobs, pnorm, qnorm, quantile, rbinom, rexp,
           rgamma, rnorm, rt, runif, residuals, sd, setNames, sigma,
           update)
importFrom(utils, combn, head, read.csv, unzip)
importFrom(graphics, abline, arrows, axis, grconvertX, grconvertY, hist, legend, mtext, par, points, polygon, rect, segments, text)
importFrom(grDevices, adjustcolor, colorRampPalette)
