% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{prior_summary.bayesqm_fit}
\alias{prior_summary.bayesqm_fit}
\title{Prior summary for a bayesqm_fit}
\usage{
\method{prior_summary}{bayesqm_fit}(object, ...)
}
\arguments{
\item{object}{A \code{bayesqm_fit}.}

\item{...}{Unused.}
}
\value{
A \code{bayesqm_prior} data frame with columns \code{parameter} and
\code{prior}.
}
\description{
The partition model's priors, as a printable \code{bayesqm_prior} object.
Method for \code{\link[=prior_summary]{prior_summary()}}.
}
