% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{prior_summary}
\alias{prior_summary}
\title{Prior summary generic}
\usage{
prior_summary(object, ...)
}
\arguments{
\item{object}{A fitted model object.}

\item{...}{Passed to methods.}
}
\value{
See the method documentation.
}
\description{
Generic for summarizing the priors a model was fit with, defined here so
the package needs no Stan-ecosystem dependency. Compatible with the
generic of the same name in \pkg{rstantools}.
}
