% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{posterior_interval.bayesqm_fit}
\alias{posterior_interval.bayesqm_fit}
\title{Credible intervals for bayesqm_fit parameters}
\usage{
\method{posterior_interval}{bayesqm_fit}(object, prob = 0.95, pars = NULL, regex_pars = NULL, ...)
}
\arguments{
\item{object}{A \code{bayesqm_fit}.}

\item{prob}{Coverage probability (default 0.95).}

\item{pars}{Optional character vector of exact parameter names.}

\item{regex_pars}{Optional regex; matching parameter names are included
in addition to those named in \code{pars}.}

\item{...}{Unused.}
}
\value{
A matrix with one row per parameter and two columns for the
lower and upper interval bounds.
}
\description{
Posterior credible intervals for any subset of parameters in a
\code{bayesqm_fit}. Method for \code{\link[=posterior_interval]{posterior_interval()}}.
}
