% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accessors.R
\name{coef.bayesqm_fit}
\alias{coef.bayesqm_fit}
\title{Posterior-mean bounded loadings}
\usage{
\method{coef}{bayesqm_fit}(object, ...)
}
\arguments{
\item{object}{A \code{bayesqm_fit}.}

\item{...}{Unused.}
}
\value{
An \verb{N x K} matrix of posterior-mean bounded loadings (the
correlation-scale loading of the accompanying paper).
}
\description{
Posterior-mean bounded loadings
}
